Learn R Programming

otrKM (version 0.2.1)

Fps.AIWKME: Logistic regression for observed treatment used for the (S)AIWKME estimator.

Description

Logistic regression for observed treatment used for the (S)AIWKME estimator.

Usage

Fps.AIWKME(datalist)

Value

A list including the probability of receiving treatment given baseline covariates named fal.

Arguments

datalist

A list used to calculate the (S)AIWKME estimator including treatment named a, observed time named obs.t, censoring indicator (0, censored) named delta, and baseline covariates used to assign treatment named l. Notice that all the data in the datalist should be ordered by observed time.

Details

More details can be found in references, AIWKME, and Genetic.optim.AIWKME.

References

Jiang, R., Lu, W., Song, R., and Davidian, M. (2017) On estimation of optimal treatment regimes for maximizing t‐year survival probability. Journal of the Royal Statistical Society: Series B (Statistical Methodology), 79: 1165-1185. DOI:10.1111/rssb.12201