Logistic regression for observed treatment and instrument used for the (S)IWKMEIV estimator.
Fps.IWKMEIV(datalist, t0)A list including the probability of receiving instrument given baseline covariates named fzl, the difference between fal1 and fal0 named deltal, where fal0 denotes the probability of receiving treatment given baseline covariates and instrument equaling 0, and fal1 denotes the probability of receiving treatment given baseline covariates and instrument equaling 1, and the censoring survival function given baseline covariates and treatment 1 or 0 named surv.C.1 or surv.C.0.
A list used to calculate the (S)IWKMEIV estimator including treatment named a, observed time named obs.t, censoring indicator (0, censored) named delta, and baseline covariates used to assign treatment named l. Notice that all the data in the datalist should be ordered by observed time.
A predetermined t.
More details can be found in references, IWKMEIV, and Genetic.optim.IWKMEIV.
Xia, J., Zhan, Z., Zhang, J. (2022) Estimating optimal treatment regime in survival contexts using an instrumental variable. Under Review.